@@ -16,6 +16,7 @@
 #' borders <- vcgBorder(humface)
 #' ## view border vertices
 #' \dontrun{
+#' require(rgl)
 #' points3d(t(humface$vb[1:3,])[which(borders$bordervb == 1),],col=2)
 #' wire3d(humface)
 #' require(rgl)
@@ -25,8 +26,14 @@ vcgBorder <- function(mesh)
     {
         if (!inherits(mesh,"mesh3d"))
             stop("argument 'mesh' needs to be object of class 'mesh3d'")
+        
         vb <- mesh$vb[1:3,]
         it <- mesh$it - 1
+        if (!is.matrix(vb))
+            stop("mesh has no vertices")
+        if (!is.matrix(it))
+            stop("mesh has no faces")
+        
         dimit <- dim(it)[2]
         dimvb <- dim(vb)[2]
         storage.mode(it) <- "integer"
