@@ -9,7 +9,7 @@ using namespace Rcpp;
 
 typedef UpdateTopology<MyMesh>::PEdge SimpleEdge;
   
-RcppExport SEXP Rmeshres(SEXP _vb , SEXP _it)
+RcppExport SEXP Rmeshres(SEXP vb_ , SEXP it_)
   {
     // declare Mesh and helper variables
     int i;
@@ -17,7 +17,7 @@ RcppExport SEXP Rmeshres(SEXP _vb , SEXP _it)
     VertexIterator vi;
     FaceIterator fi;
     
-    Rvcg::IOMesh<MyMesh>::RvcgReadR(m,_vb,_it);
+    Rvcg::IOMesh<MyMesh>::RvcgReadR(m,vb_,it_);
     /*m.vert.EnableVFAdjacency();
     m.face.EnableFFAdjacency();
     m.face.EnableVFAdjacency();*/
